package org.robolectric;
import android.accessibilityservice.AccessibilityService;
import android.accounts.AccountManager;
import android.animation.ObjectAnimator;
import android.animation.ValueAnimator;
import android.app.Activity;
import android.app.ActivityGroup;
import android.app.ActivityManager;
import android.app.AlarmManager;
import android.app.AlertDialog;
import android.app.AlertDialog.Builder;
import android.app.Application;
import android.app.DatePickerDialog;
import android.app.Dialog;
import android.app.DownloadManager;
import android.app.DownloadManager.Query;
import android.app.DownloadManager.Request;
import android.app.IntentService;
import android.app.KeyguardManager;
import android.app.KeyguardManager.KeyguardLock;
import android.app.LocalActivityManager;
import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.ProgressDialog;
import android.app.SearchManager;
import android.app.Service;
import android.app.TabActivity;
import android.app.TimePickerDialog;
import android.app.WallpaperManager;
import android.appwidget.AppWidgetHost;
import android.appwidget.AppWidgetHostView;
import android.appwidget.AppWidgetManager;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.AsyncTaskLoader;
import android.content.BroadcastReceiver;
import android.content.BroadcastReceiver.PendingResult;
import android.content.ClipboardManager;
import android.content.ContentProvider;
import android.content.ContentProviderClient;
import android.content.ContentProviderOperation;
import android.content.ContentProviderResult;
import android.content.ContentResolver;
import android.content.ContentUris;
import android.content.ContextWrapper;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.IntentFilter.AuthorityEntry;
import android.content.pm.ResolveInfo;
import android.content.res.AssetManager;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.content.res.Resources.NotFoundException;
import android.content.res.Resources.Theme;
import android.content.res.TypedArray;
import android.database.AbstractCursor;
import android.database.ContentObserver;
import android.database.CursorWindow;
import android.database.CursorWrapper;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.ColorMatrix;
import android.graphics.ColorMatrixColorFilter;
import android.graphics.CornerPathEffect;
import android.graphics.DashPathEffect;
import android.graphics.LinearGradient;
import android.graphics.Matrix;
import android.graphics.NinePatch;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Picture;
import android.graphics.PorterDuffColorFilter;
import android.graphics.Region;
import android.graphics.Typeface;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.GradientDrawable;
import android.graphics.drawable.StateListDrawable;
import android.hardware.Camera;
import android.hardware.Camera.Parameters;
import android.hardware.Camera.Size;
import android.hardware.SensorManager;
import android.location.Location;
import android.location.LocationManager;
import android.media.AudioManager;
import android.media.ExifInterface;
import android.media.MediaMetadataRetriever;
import android.media.MediaPlayer;
import android.media.MediaRecorder;
import android.media.MediaRouter;
import android.media.MediaScannerConnection;
import android.media.SoundPool;
import android.media.audiofx.AudioEffect;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.TrafficStats;
import android.net.http.HttpResponseCache;
import android.net.wifi.ScanResult;
import android.net.wifi.WifiConfiguration;
import android.net.wifi.WifiInfo;
import android.net.wifi.WifiManager;
import android.net.wifi.WifiManager.WifiLock;
import android.nfc.NfcAdapter;
import android.os.AsyncTask;
import android.os.Binder;
import android.os.CountDownTimer;
import android.os.Debug;
import android.os.Environment;
import android.os.Handler;
import android.os.IInterface;
import android.os.Looper;
import android.os.Message;
import android.os.MessageQueue;
import android.os.Messenger;
import android.os.Parcel;
import android.os.ParcelFileDescriptor;
import android.os.PowerManager;
import android.os.PowerManager.WakeLock;
import android.os.Process;
import android.os.RemoteCallbackList;
import android.os.ResultReceiver;
import android.os.StatFs;
import android.os.StrictMode;
import android.os.SystemClock;
import android.preference.Preference;
import android.provider.MediaStore;
import android.provider.MediaStore.Images;
import android.provider.MediaStore.Images.Media;
import android.provider.Settings;
import android.provider.Settings.Secure;
import android.provider.Settings.System;
import android.speech.tts.TextToSpeech;
import android.telephony.TelephonyManager;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.text.format.DateFormat;
import android.text.format.Time;
import android.text.method.LinkMovementMethod;
import android.util.FloatMath;
import android.util.Log;
import android.view.Choreographer;
import android.view.ContextThemeWrapper;
import android.view.Display;
import android.view.GestureDetector;
import android.view.InputDevice;
import android.view.InputEvent;
import android.view.KeyCharacterMap;
import android.view.MotionEvent;
import android.view.ScaleGestureDetector;
import android.view.Surface;
import android.view.SurfaceView;
import android.view.TouchDelegate;
import android.view.VelocityTracker;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.ViewGroup.MarginLayoutParams;
import android.view.Window;
import android.view.WindowManager;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityManager;
import android.view.accessibility.AccessibilityNodeInfo;
import android.view.accessibility.AccessibilityRecord;
import android.view.animation.AnimationUtils;
import android.view.animation.LayoutAnimationController;
import android.view.inputmethod.InputMethodManager;
import android.webkit.CookieManager;
import android.webkit.CookieSyncManager;
import android.webkit.JsPromptResult;
import android.webkit.JsResult;
import android.webkit.MimeTypeMap;
import android.webkit.SslErrorHandler;
import android.webkit.WebView;
import android.webkit.WebViewDatabase;
import android.widget.AbsListView;
import android.widget.AbsSeekBar;
import android.widget.AbsSpinner;
import android.widget.AbsoluteLayout;
import android.widget.Adapter;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.BaseAdapter;
import android.widget.CompoundButton;
import android.widget.CursorAdapter;
import android.widget.EdgeEffect;
import android.widget.ExpandableListView;
import android.widget.Filter;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ListPopupWindow;
import android.widget.ListView;
import android.widget.NumberPicker;
import android.widget.OverScroller;
import android.widget.PopupMenu;
import android.widget.PopupWindow;
import android.widget.ProgressBar;
import android.widget.RelativeLayout;
import android.widget.ResourceCursorAdapter;
import android.widget.ScrollView;
import android.widget.Scroller;
import android.widget.SeekBar;
import android.widget.SimpleCursorAdapter;
import android.widget.TabHost;
import android.widget.TabHost.TabSpec;
import android.widget.TabWidget;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.VideoView;
import android.widget.ViewAnimator;
import android.widget.ZoomButtonsController;
import java.util.HashMap;
import java.util.Map;
import javax.annotation.Generated;
import org.robolectric.internal.ShadowExtractor;
import org.robolectric.internal.ShadowProvider;
import org.robolectric.shadows.ShadowAbsListView;
import org.robolectric.shadows.ShadowAbsSeekBar;
import org.robolectric.shadows.ShadowAbsSpinner;
import org.robolectric.shadows.ShadowAbsoluteLayout;
import org.robolectric.shadows.ShadowAbstractCursor;
import org.robolectric.shadows.ShadowAccessibilityEvent;
import org.robolectric.shadows.ShadowAccessibilityManager;
import org.robolectric.shadows.ShadowAccessibilityNodeInfo;
import org.robolectric.shadows.ShadowAccessibilityRecord;
import org.robolectric.shadows.ShadowAccessibilityService;
import org.robolectric.shadows.ShadowAccountManager;
import org.robolectric.shadows.ShadowActivity;
import org.robolectric.shadows.ShadowActivityGroup;
import org.robolectric.shadows.ShadowActivityManager;
import org.robolectric.shadows.ShadowAdapterView;
import org.robolectric.shadows.ShadowAlarmManager;
import org.robolectric.shadows.ShadowAlertDialog;
import org.robolectric.shadows.ShadowAlertDialog.ShadowBuilder;
import org.robolectric.shadows.ShadowAndroidBidi;
import org.robolectric.shadows.ShadowAnimationUtils;
import org.robolectric.shadows.ShadowAppWidgetHost;
import org.robolectric.shadows.ShadowAppWidgetHostView;
import org.robolectric.shadows.ShadowAppWidgetManager;
import org.robolectric.shadows.ShadowApplication;
import org.robolectric.shadows.ShadowArrayAdapter;
import org.robolectric.shadows.ShadowAssetManager;
import org.robolectric.shadows.ShadowAsyncTask;
import org.robolectric.shadows.ShadowAsyncTaskLoader;
import org.robolectric.shadows.ShadowAudioEffect;
import org.robolectric.shadows.ShadowAudioManager;
import org.robolectric.shadows.ShadowBaseAdapter;
import org.robolectric.shadows.ShadowBinder;
import org.robolectric.shadows.ShadowBitmap;
import org.robolectric.shadows.ShadowBitmapDrawable;
import org.robolectric.shadows.ShadowBitmapFactory;
import org.robolectric.shadows.ShadowBitmapShader;
import org.robolectric.shadows.ShadowBluetoothAdapter;
import org.robolectric.shadows.ShadowBluetoothDevice;
import org.robolectric.shadows.ShadowBroadcastPendingResult;
import org.robolectric.shadows.ShadowBroadcastReceiver;
import org.robolectric.shadows.ShadowCamera;
import org.robolectric.shadows.ShadowCamera.ShadowParameters;
import org.robolectric.shadows.ShadowCamera.ShadowSize;
import org.robolectric.shadows.ShadowCanvas;
import org.robolectric.shadows.ShadowChoreographer;
import org.robolectric.shadows.ShadowClipboardManager;
import org.robolectric.shadows.ShadowColor;
import org.robolectric.shadows.ShadowColorMatrix;
import org.robolectric.shadows.ShadowColorMatrixColorFilter;
import org.robolectric.shadows.ShadowCompoundButton;
import org.robolectric.shadows.ShadowConfiguration;
import org.robolectric.shadows.ShadowConnectivityManager;
import org.robolectric.shadows.ShadowContentObserver;
import org.robolectric.shadows.ShadowContentProvider;
import org.robolectric.shadows.ShadowContentProviderClient;
import org.robolectric.shadows.ShadowContentProviderOperation;
import org.robolectric.shadows.ShadowContentProviderResult;
import org.robolectric.shadows.ShadowContentResolver;
import org.robolectric.shadows.ShadowContentUris;
import org.robolectric.shadows.ShadowContextImpl;
import org.robolectric.shadows.ShadowContextImpl.ShadowServiceFetcher;
import org.robolectric.shadows.ShadowContextThemeWrapper;
import org.robolectric.shadows.ShadowContextWrapper;
import org.robolectric.shadows.ShadowCookieManager;
import org.robolectric.shadows.ShadowCookieSyncManager;
import org.robolectric.shadows.ShadowCornerPathEffect;
import org.robolectric.shadows.ShadowCountDownTimer;
import org.robolectric.shadows.ShadowCursorAdapter;
import org.robolectric.shadows.ShadowCursorWindow;
import org.robolectric.shadows.ShadowCursorWrapper;
import org.robolectric.shadows.ShadowDashPathEffect;
import org.robolectric.shadows.ShadowDateFormat;
import org.robolectric.shadows.ShadowDatePickerDialog;
import org.robolectric.shadows.ShadowDebug;
import org.robolectric.shadows.ShadowDialog;
import org.robolectric.shadows.ShadowDisplay;
import org.robolectric.shadows.ShadowDownloadManager;
import org.robolectric.shadows.ShadowDownloadManager.ShadowQuery;
import org.robolectric.shadows.ShadowDownloadManager.ShadowRequest;
import org.robolectric.shadows.ShadowDrawable;
import org.robolectric.shadows.ShadowEdgeEffect;
import org.robolectric.shadows.ShadowEnvironment;
import org.robolectric.shadows.ShadowExifInterface;
import org.robolectric.shadows.ShadowExpandableListView;
import org.robolectric.shadows.ShadowFilter;
import org.robolectric.shadows.ShadowFloatMath;
import org.robolectric.shadows.ShadowFrameLayout;
import org.robolectric.shadows.ShadowGestureDetector;
import org.robolectric.shadows.ShadowGradientDrawable;
import org.robolectric.shadows.ShadowHandler;
import org.robolectric.shadows.ShadowHttpResponseCache;
import org.robolectric.shadows.ShadowImageView;
import org.robolectric.shadows.ShadowInputDevice;
import org.robolectric.shadows.ShadowInputEvent;
import org.robolectric.shadows.ShadowInputMethodManager;
import org.robolectric.shadows.ShadowIntent;
import org.robolectric.shadows.ShadowIntentFilter;
import org.robolectric.shadows.ShadowIntentFilter.ShadowAuthorityEntry;
import org.robolectric.shadows.ShadowIntentService;
import org.robolectric.shadows.ShadowJsPromptResult;
import org.robolectric.shadows.ShadowJsResult;
import org.robolectric.shadows.ShadowKeyCharacterMap;
import org.robolectric.shadows.ShadowKeyguardManager;
import org.robolectric.shadows.ShadowKeyguardManager.ShadowKeyguardLock;
import org.robolectric.shadows.ShadowLayoutAnimationController;
import org.robolectric.shadows.ShadowLinearGradient;
import org.robolectric.shadows.ShadowLinearLayout;
import org.robolectric.shadows.ShadowLinkMovementMethod;
import org.robolectric.shadows.ShadowListPopupWindow;
import org.robolectric.shadows.ShadowListView;
import org.robolectric.shadows.ShadowLocalActivityManager;
import org.robolectric.shadows.ShadowLocation;
import org.robolectric.shadows.ShadowLocationManager;
import org.robolectric.shadows.ShadowLog;
import org.robolectric.shadows.ShadowLooper;
import org.robolectric.shadows.ShadowMatrix;
import org.robolectric.shadows.ShadowMediaMetadataRetriever;
import org.robolectric.shadows.ShadowMediaPlayer;
import org.robolectric.shadows.ShadowMediaRecorder;
import org.robolectric.shadows.ShadowMediaRouter;
import org.robolectric.shadows.ShadowMediaScannerConnection;
import org.robolectric.shadows.ShadowMediaStore;
import org.robolectric.shadows.ShadowMediaStore.ShadowImages;
import org.robolectric.shadows.ShadowMediaStore.ShadowImages.ShadowMedia;
import org.robolectric.shadows.ShadowMessage;
import org.robolectric.shadows.ShadowMessageQueue;
import org.robolectric.shadows.ShadowMessenger;
import org.robolectric.shadows.ShadowMimeTypeMap;
import org.robolectric.shadows.ShadowMotionEvent;
import org.robolectric.shadows.ShadowNetworkInfo;
import org.robolectric.shadows.ShadowNfcAdapter;
import org.robolectric.shadows.ShadowNinePatch;
import org.robolectric.shadows.ShadowNotification;
import org.robolectric.shadows.ShadowNotificationManager;
import org.robolectric.shadows.ShadowNumberPicker;
import org.robolectric.shadows.ShadowObjectAnimator;
import org.robolectric.shadows.ShadowOverScroller;
import org.robolectric.shadows.ShadowPaint;
import org.robolectric.shadows.ShadowParcel;
import org.robolectric.shadows.ShadowParcelFileDescriptor;
import org.robolectric.shadows.ShadowPath;
import org.robolectric.shadows.ShadowPendingIntent;
import org.robolectric.shadows.ShadowPicture;
import org.robolectric.shadows.ShadowPopupMenu;
import org.robolectric.shadows.ShadowPopupWindow;
import org.robolectric.shadows.ShadowPorterDuffColorFilter;
import org.robolectric.shadows.ShadowPowerManager;
import org.robolectric.shadows.ShadowPowerManager.ShadowWakeLock;
import org.robolectric.shadows.ShadowPreference;
import org.robolectric.shadows.ShadowProcess;
import org.robolectric.shadows.ShadowProgressBar;
import org.robolectric.shadows.ShadowProgressDialog;
import org.robolectric.shadows.ShadowRegion;
import org.robolectric.shadows.ShadowRelativeLayout;
import org.robolectric.shadows.ShadowRemoteCallbackList;
import org.robolectric.shadows.ShadowResolveInfo;
import org.robolectric.shadows.ShadowResourceCursorAdapter;
import org.robolectric.shadows.ShadowResources;
import org.robolectric.shadows.ShadowResources.ShadowNotFoundException;
import org.robolectric.shadows.ShadowResources.ShadowTheme;
import org.robolectric.shadows.ShadowResultReceiver;
import org.robolectric.shadows.ShadowSQLiteConnection;
import org.robolectric.shadows.ShadowScaleGestureDetector;
import org.robolectric.shadows.ShadowScanResult;
import org.robolectric.shadows.ShadowScrollView;
import org.robolectric.shadows.ShadowScroller;
import org.robolectric.shadows.ShadowSearchManager;
import org.robolectric.shadows.ShadowSeekBar;
import org.robolectric.shadows.ShadowSensorManager;
import org.robolectric.shadows.ShadowService;
import org.robolectric.shadows.ShadowSettings;
import org.robolectric.shadows.ShadowSettings.ShadowSecure;
import org.robolectric.shadows.ShadowSettings.ShadowSystem;
import org.robolectric.shadows.ShadowSimpleCursorAdapter;
import org.robolectric.shadows.ShadowSoundPool;
import org.robolectric.shadows.ShadowSslErrorHandler;
import org.robolectric.shadows.ShadowStatFs;
import org.robolectric.shadows.ShadowStateListDrawable;
import org.robolectric.shadows.ShadowStaticLayout;
import org.robolectric.shadows.ShadowStrictMode;
import org.robolectric.shadows.ShadowSurface;
import org.robolectric.shadows.ShadowSurfaceView;
import org.robolectric.shadows.ShadowSystemClock;
import org.robolectric.shadows.ShadowTabActivity;
import org.robolectric.shadows.ShadowTabHost;
import org.robolectric.shadows.ShadowTabHost.ShadowTabSpec;
import org.robolectric.shadows.ShadowTabWidget;
import org.robolectric.shadows.ShadowTelephonyManager;
import org.robolectric.shadows.ShadowTextPaint;
import org.robolectric.shadows.ShadowTextToSpeech;
import org.robolectric.shadows.ShadowTextView;
import org.robolectric.shadows.ShadowTime;
import org.robolectric.shadows.ShadowTimePickerDialog;
import org.robolectric.shadows.ShadowToast;
import org.robolectric.shadows.ShadowTouchDelegate;
import org.robolectric.shadows.ShadowTrafficStats;
import org.robolectric.shadows.ShadowTypedArray;
import org.robolectric.shadows.ShadowTypeface;
import org.robolectric.shadows.ShadowValueAnimator;
import org.robolectric.shadows.ShadowVelocityTracker;
import org.robolectric.shadows.ShadowVideoView;
import org.robolectric.shadows.ShadowView;
import org.robolectric.shadows.ShadowViewAnimator;
import org.robolectric.shadows.ShadowViewConfiguration;
import org.robolectric.shadows.ShadowViewGroup;
import org.robolectric.shadows.ShadowViewGroup.ShadowMarginLayoutParams;
import org.robolectric.shadows.ShadowWallpaperManager;
import org.robolectric.shadows.ShadowWebSyncManager;
import org.robolectric.shadows.ShadowWebView;
import org.robolectric.shadows.ShadowWebViewDatabase;
import org.robolectric.shadows.ShadowWifiConfiguration;
import org.robolectric.shadows.ShadowWifiInfo;
import org.robolectric.shadows.ShadowWifiManager;
import org.robolectric.shadows.ShadowWifiManager.ShadowWifiLock;
import org.robolectric.shadows.ShadowWindow;
import org.robolectric.shadows.ShadowWindowManager;
import org.robolectric.shadows.ShadowZoomButtonsController;

/**
 * Shadow mapper. Automatically generated by the Robolectric Annotation Processor.
 */
@Generated("org.robolectric.annotation.processing.RobolectricProcessor")
@SuppressWarnings({"unchecked","deprecation"})
public class Shadows implements ShadowProvider {
  private static final Map<String, String> SHADOW_MAP = new HashMap<>(233);

  static {
    SHADOW_MAP.put("android.widget.AbsListView", "org.robolectric.shadows.ShadowAbsListView");
    SHADOW_MAP.put("android.widget.AbsSeekBar", "org.robolectric.shadows.ShadowAbsSeekBar");
    SHADOW_MAP.put("android.widget.AbsSpinner", "org.robolectric.shadows.ShadowAbsSpinner");
    SHADOW_MAP.put("android.widget.AbsoluteLayout", "org.robolectric.shadows.ShadowAbsoluteLayout");
    SHADOW_MAP.put("android.widget.AbsoluteLayout.LayoutParams", "org.robolectric.shadows.ShadowAbsoluteLayout$ShadowLayoutParams");
    SHADOW_MAP.put("android.database.AbstractCursor", "org.robolectric.shadows.ShadowAbstractCursor");
    SHADOW_MAP.put("android.view.accessibility.AccessibilityEvent", "org.robolectric.shadows.ShadowAccessibilityEvent");
    SHADOW_MAP.put("android.view.accessibility.AccessibilityManager", "org.robolectric.shadows.ShadowAccessibilityManager");
    SHADOW_MAP.put("android.view.accessibility.AccessibilityNodeInfo", "org.robolectric.shadows.ShadowAccessibilityNodeInfo");
    SHADOW_MAP.put("android.view.accessibility.AccessibilityRecord", "org.robolectric.shadows.ShadowAccessibilityRecord");
    SHADOW_MAP.put("android.accessibilityservice.AccessibilityService", "org.robolectric.shadows.ShadowAccessibilityService");
    SHADOW_MAP.put("android.accounts.AccountManager", "org.robolectric.shadows.ShadowAccountManager");
    SHADOW_MAP.put("android.app.Activity", "org.robolectric.shadows.ShadowActivity");
    SHADOW_MAP.put("android.app.ActivityGroup", "org.robolectric.shadows.ShadowActivityGroup");
    SHADOW_MAP.put("android.app.ActivityManager", "org.robolectric.shadows.ShadowActivityManager");
    SHADOW_MAP.put("android.app.ActivityManagerNative", "org.robolectric.shadows.ShadowActivityManagerNative");
    SHADOW_MAP.put("android.app.ActivityThread", "org.robolectric.shadows.ShadowActivityThread");
    SHADOW_MAP.put("android.widget.AdapterView", "org.robolectric.shadows.ShadowAdapterView");
    SHADOW_MAP.put("android.app.AlarmManager", "org.robolectric.shadows.ShadowAlarmManager");
    SHADOW_MAP.put("com.android.internal.app.AlertController", "org.robolectric.shadows.ShadowAlertController");
    SHADOW_MAP.put("android.app.AlertDialog", "org.robolectric.shadows.ShadowAlertDialog");
    SHADOW_MAP.put("android.app.AlertDialog.Builder", "org.robolectric.shadows.ShadowAlertDialog$ShadowBuilder");
    SHADOW_MAP.put("android.text.AndroidBidi", "org.robolectric.shadows.ShadowAndroidBidi");
    SHADOW_MAP.put("android.view.animation.AnimationUtils", "org.robolectric.shadows.ShadowAnimationUtils");
    SHADOW_MAP.put("android.appwidget.AppWidgetHost", "org.robolectric.shadows.ShadowAppWidgetHost");
    SHADOW_MAP.put("android.appwidget.AppWidgetHostView", "org.robolectric.shadows.ShadowAppWidgetHostView");
    SHADOW_MAP.put("android.appwidget.AppWidgetManager", "org.robolectric.shadows.ShadowAppWidgetManager");
    SHADOW_MAP.put("android.app.Application", "org.robolectric.shadows.ShadowApplication");
    SHADOW_MAP.put("android.widget.ArrayAdapter", "org.robolectric.shadows.ShadowArrayAdapter");
    SHADOW_MAP.put("android.content.res.AssetManager", "org.robolectric.shadows.ShadowAssetManager");
    SHADOW_MAP.put("android.os.AsyncTask", "org.robolectric.shadows.ShadowAsyncTask");
    SHADOW_MAP.put("android.content.AsyncTaskLoader", "org.robolectric.shadows.ShadowAsyncTaskLoader");
    SHADOW_MAP.put("android.media.audiofx.AudioEffect", "org.robolectric.shadows.ShadowAudioEffect");
    SHADOW_MAP.put("android.media.AudioManager", "org.robolectric.shadows.ShadowAudioManager");
    SHADOW_MAP.put("android.widget.BaseAdapter", "org.robolectric.shadows.ShadowBaseAdapter");
    SHADOW_MAP.put("android.os.Binder", "org.robolectric.shadows.ShadowBinder");
    SHADOW_MAP.put("android.graphics.Bitmap", "org.robolectric.shadows.ShadowBitmap");
    SHADOW_MAP.put("android.graphics.drawable.BitmapDrawable", "org.robolectric.shadows.ShadowBitmapDrawable");
    SHADOW_MAP.put("android.graphics.BitmapFactory", "org.robolectric.shadows.ShadowBitmapFactory");
    SHADOW_MAP.put("android.graphics.BitmapShader", "org.robolectric.shadows.ShadowBitmapShader");
    SHADOW_MAP.put("android.bluetooth.BluetoothAdapter", "org.robolectric.shadows.ShadowBluetoothAdapter");
    SHADOW_MAP.put("android.bluetooth.BluetoothDevice", "org.robolectric.shadows.ShadowBluetoothDevice");
    SHADOW_MAP.put("android.content.BroadcastReceiver.PendingResult", "org.robolectric.shadows.ShadowBroadcastPendingResult");
    SHADOW_MAP.put("android.content.BroadcastReceiver", "org.robolectric.shadows.ShadowBroadcastReceiver");
    SHADOW_MAP.put("android.hardware.Camera", "org.robolectric.shadows.ShadowCamera");
    SHADOW_MAP.put("android.hardware.Camera.Parameters", "org.robolectric.shadows.ShadowCamera$ShadowParameters");
    SHADOW_MAP.put("android.hardware.Camera.Size", "org.robolectric.shadows.ShadowCamera$ShadowSize");
    SHADOW_MAP.put("android.graphics.Canvas", "org.robolectric.shadows.ShadowCanvas");
    SHADOW_MAP.put("android.view.Choreographer", "org.robolectric.shadows.ShadowChoreographer");
    SHADOW_MAP.put("android.content.ClipboardManager", "org.robolectric.shadows.ShadowClipboardManager");
    SHADOW_MAP.put("android.graphics.Color", "org.robolectric.shadows.ShadowColor");
    SHADOW_MAP.put("android.graphics.ColorMatrix", "org.robolectric.shadows.ShadowColorMatrix");
    SHADOW_MAP.put("android.graphics.ColorMatrixColorFilter", "org.robolectric.shadows.ShadowColorMatrixColorFilter");
    SHADOW_MAP.put("android.widget.CompoundButton", "org.robolectric.shadows.ShadowCompoundButton");
    SHADOW_MAP.put("android.content.res.Configuration", "org.robolectric.shadows.ShadowConfiguration");
    SHADOW_MAP.put("android.net.ConnectivityManager", "org.robolectric.shadows.ShadowConnectivityManager");
    SHADOW_MAP.put("android.database.ContentObserver", "org.robolectric.shadows.ShadowContentObserver");
    SHADOW_MAP.put("android.content.ContentProvider", "org.robolectric.shadows.ShadowContentProvider");
    SHADOW_MAP.put("android.content.ContentProviderClient", "org.robolectric.shadows.ShadowContentProviderClient");
    SHADOW_MAP.put("android.content.ContentProviderOperation", "org.robolectric.shadows.ShadowContentProviderOperation");
    SHADOW_MAP.put("android.content.ContentProviderResult", "org.robolectric.shadows.ShadowContentProviderResult");
    SHADOW_MAP.put("android.content.ContentResolver", "org.robolectric.shadows.ShadowContentResolver");
    SHADOW_MAP.put("android.content.ContentUris", "org.robolectric.shadows.ShadowContentUris");
    SHADOW_MAP.put("android.app.ContextImpl", "org.robolectric.shadows.ShadowContextImpl");
    SHADOW_MAP.put("android.app.ContextImpl.ServiceFetcher", "org.robolectric.shadows.ShadowContextImpl$ShadowServiceFetcher");
    SHADOW_MAP.put("android.view.ContextThemeWrapper", "org.robolectric.shadows.ShadowContextThemeWrapper");
    SHADOW_MAP.put("android.content.ContextWrapper", "org.robolectric.shadows.ShadowContextWrapper");
    SHADOW_MAP.put("android.webkit.CookieManager", "org.robolectric.shadows.ShadowCookieManager");
    SHADOW_MAP.put("android.webkit.CookieSyncManager", "org.robolectric.shadows.ShadowCookieSyncManager");
    SHADOW_MAP.put("android.graphics.CornerPathEffect", "org.robolectric.shadows.ShadowCornerPathEffect");
    SHADOW_MAP.put("android.os.CountDownTimer", "org.robolectric.shadows.ShadowCountDownTimer");
    SHADOW_MAP.put("android.widget.CursorAdapter", "org.robolectric.shadows.ShadowCursorAdapter");
    SHADOW_MAP.put("android.database.CursorWindow", "org.robolectric.shadows.ShadowCursorWindow");
    SHADOW_MAP.put("android.database.CursorWrapper", "org.robolectric.shadows.ShadowCursorWrapper");
    SHADOW_MAP.put("android.graphics.DashPathEffect", "org.robolectric.shadows.ShadowDashPathEffect");
    SHADOW_MAP.put("android.text.format.DateFormat", "org.robolectric.shadows.ShadowDateFormat");
    SHADOW_MAP.put("android.app.DatePickerDialog", "org.robolectric.shadows.ShadowDatePickerDialog");
    SHADOW_MAP.put("android.os.Debug", "org.robolectric.shadows.ShadowDebug");
    SHADOW_MAP.put("android.app.Dialog", "org.robolectric.shadows.ShadowDialog");
    SHADOW_MAP.put("android.view.Display", "org.robolectric.shadows.ShadowDisplay");
    SHADOW_MAP.put("android.app.DownloadManager", "org.robolectric.shadows.ShadowDownloadManager");
    SHADOW_MAP.put("android.app.DownloadManager.Query", "org.robolectric.shadows.ShadowDownloadManager$ShadowQuery");
    SHADOW_MAP.put("android.app.DownloadManager.Request", "org.robolectric.shadows.ShadowDownloadManager$ShadowRequest");
    SHADOW_MAP.put("android.graphics.drawable.Drawable", "org.robolectric.shadows.ShadowDrawable");
    SHADOW_MAP.put("android.widget.EdgeEffect", "org.robolectric.shadows.ShadowEdgeEffect");
    SHADOW_MAP.put("android.os.Environment", "org.robolectric.shadows.ShadowEnvironment");
    SHADOW_MAP.put("android.media.ExifInterface", "org.robolectric.shadows.ShadowExifInterface");
    SHADOW_MAP.put("android.widget.ExpandableListView", "org.robolectric.shadows.ShadowExpandableListView");
    SHADOW_MAP.put("android.widget.Filter", "org.robolectric.shadows.ShadowFilter");
    SHADOW_MAP.put("android.util.FloatMath", "org.robolectric.shadows.ShadowFloatMath");
    SHADOW_MAP.put("android.widget.FrameLayout", "org.robolectric.shadows.ShadowFrameLayout");
    SHADOW_MAP.put("android.view.GestureDetector", "org.robolectric.shadows.ShadowGestureDetector");
    SHADOW_MAP.put("android.graphics.drawable.GradientDrawable", "org.robolectric.shadows.ShadowGradientDrawable");
    SHADOW_MAP.put("android.os.Handler", "org.robolectric.shadows.ShadowHandler");
    SHADOW_MAP.put("android.net.http.HttpResponseCache", "org.robolectric.shadows.ShadowHttpResponseCache");
    SHADOW_MAP.put("libcore.icu.ICU", "org.robolectric.shadows.ShadowICU");
    SHADOW_MAP.put("android.widget.ImageView", "org.robolectric.shadows.ShadowImageView");
    SHADOW_MAP.put("android.view.InputDevice", "org.robolectric.shadows.ShadowInputDevice");
    SHADOW_MAP.put("android.view.InputEvent", "org.robolectric.shadows.ShadowInputEvent");
    SHADOW_MAP.put("android.view.inputmethod.InputMethodManager", "org.robolectric.shadows.ShadowInputMethodManager");
    SHADOW_MAP.put("android.content.Intent", "org.robolectric.shadows.ShadowIntent");
    SHADOW_MAP.put("android.content.IntentFilter", "org.robolectric.shadows.ShadowIntentFilter");
    SHADOW_MAP.put("android.content.IntentFilter.AuthorityEntry", "org.robolectric.shadows.ShadowIntentFilter$ShadowAuthorityEntry");
    SHADOW_MAP.put("android.app.IntentService", "org.robolectric.shadows.ShadowIntentService");
    SHADOW_MAP.put("android.webkit.JsPromptResult", "org.robolectric.shadows.ShadowJsPromptResult");
    SHADOW_MAP.put("android.webkit.JsResult", "org.robolectric.shadows.ShadowJsResult");
    SHADOW_MAP.put("android.view.KeyCharacterMap", "org.robolectric.shadows.ShadowKeyCharacterMap");
    SHADOW_MAP.put("android.app.KeyguardManager", "org.robolectric.shadows.ShadowKeyguardManager");
    SHADOW_MAP.put("android.app.KeyguardManager.KeyguardLock", "org.robolectric.shadows.ShadowKeyguardManager$ShadowKeyguardLock");
    SHADOW_MAP.put("android.view.animation.LayoutAnimationController", "org.robolectric.shadows.ShadowLayoutAnimationController");
    SHADOW_MAP.put("android.graphics.LinearGradient", "org.robolectric.shadows.ShadowLinearGradient");
    SHADOW_MAP.put("android.widget.LinearLayout", "org.robolectric.shadows.ShadowLinearLayout");
    SHADOW_MAP.put("android.text.method.LinkMovementMethod", "org.robolectric.shadows.ShadowLinkMovementMethod");
    SHADOW_MAP.put("android.widget.ListPopupWindow", "org.robolectric.shadows.ShadowListPopupWindow");
    SHADOW_MAP.put("android.widget.ListView", "org.robolectric.shadows.ShadowListView");
    SHADOW_MAP.put("android.app.LocalActivityManager", "org.robolectric.shadows.ShadowLocalActivityManager");
    SHADOW_MAP.put("libcore.icu.LocaleData", "org.robolectric.shadows.ShadowLocaleData");
    SHADOW_MAP.put("android.location.Location", "org.robolectric.shadows.ShadowLocation");
    SHADOW_MAP.put("android.location.LocationManager", "org.robolectric.shadows.ShadowLocationManager");
    SHADOW_MAP.put("android.util.Log", "org.robolectric.shadows.ShadowLog");
    SHADOW_MAP.put("android.os.Looper", "org.robolectric.shadows.ShadowLooper");
    SHADOW_MAP.put("android.graphics.Matrix", "org.robolectric.shadows.ShadowMatrix");
    SHADOW_MAP.put("android.media.MediaMetadataRetriever", "org.robolectric.shadows.ShadowMediaMetadataRetriever");
    SHADOW_MAP.put("android.media.MediaPlayer", "org.robolectric.shadows.ShadowMediaPlayer");
    SHADOW_MAP.put("android.media.MediaRecorder", "org.robolectric.shadows.ShadowMediaRecorder");
    SHADOW_MAP.put("android.media.MediaRouter", "org.robolectric.shadows.ShadowMediaRouter");
    SHADOW_MAP.put("android.media.MediaScannerConnection", "org.robolectric.shadows.ShadowMediaScannerConnection");
    SHADOW_MAP.put("android.provider.MediaStore", "org.robolectric.shadows.ShadowMediaStore");
    SHADOW_MAP.put("android.provider.MediaStore.Images", "org.robolectric.shadows.ShadowMediaStore$ShadowImages");
    SHADOW_MAP.put("android.provider.MediaStore.Images.Media", "org.robolectric.shadows.ShadowMediaStore$ShadowImages$ShadowMedia");
    SHADOW_MAP.put("libcore.io.MemoryMappedFile", "org.robolectric.shadows.ShadowMemoryMappedFile");
    SHADOW_MAP.put("android.os.Message", "org.robolectric.shadows.ShadowMessage");
    SHADOW_MAP.put("android.os.MessageQueue", "org.robolectric.shadows.ShadowMessageQueue");
    SHADOW_MAP.put("android.os.Messenger", "org.robolectric.shadows.ShadowMessenger");
    SHADOW_MAP.put("android.webkit.MimeTypeMap", "org.robolectric.shadows.ShadowMimeTypeMap");
    SHADOW_MAP.put("android.view.MotionEvent", "org.robolectric.shadows.ShadowMotionEvent");
    SHADOW_MAP.put("android.net.NetworkInfo", "org.robolectric.shadows.ShadowNetworkInfo");
    SHADOW_MAP.put("android.nfc.NfcAdapter", "org.robolectric.shadows.ShadowNfcAdapter");
    SHADOW_MAP.put("android.graphics.NinePatch", "org.robolectric.shadows.ShadowNinePatch");
    SHADOW_MAP.put("android.app.Notification", "org.robolectric.shadows.ShadowNotification");
    SHADOW_MAP.put("android.app.NotificationManager", "org.robolectric.shadows.ShadowNotificationManager");
    SHADOW_MAP.put("android.widget.NumberPicker", "org.robolectric.shadows.ShadowNumberPicker");
    SHADOW_MAP.put("android.animation.ObjectAnimator", "org.robolectric.shadows.ShadowObjectAnimator");
    SHADOW_MAP.put("android.widget.OverScroller", "org.robolectric.shadows.ShadowOverScroller");
    SHADOW_MAP.put("android.graphics.Paint", "org.robolectric.shadows.ShadowPaint");
    SHADOW_MAP.put("android.os.Parcel", "org.robolectric.shadows.ShadowParcel");
    SHADOW_MAP.put("android.os.ParcelFileDescriptor", "org.robolectric.shadows.ShadowParcelFileDescriptor");
    SHADOW_MAP.put("android.graphics.Path", "org.robolectric.shadows.ShadowPath");
    SHADOW_MAP.put("android.app.PendingIntent", "org.robolectric.shadows.ShadowPendingIntent");
    SHADOW_MAP.put("com.android.internal.policy.impl.PhoneWindow", "org.robolectric.shadows.ShadowPhoneWindow");
    SHADOW_MAP.put("android.graphics.Picture", "org.robolectric.shadows.ShadowPicture");
    SHADOW_MAP.put("android.widget.PopupMenu", "org.robolectric.shadows.ShadowPopupMenu");
    SHADOW_MAP.put("android.widget.PopupWindow", "org.robolectric.shadows.ShadowPopupWindow");
    SHADOW_MAP.put("android.graphics.PorterDuffColorFilter", "org.robolectric.shadows.ShadowPorterDuffColorFilter");
    SHADOW_MAP.put("android.os.PowerManager", "org.robolectric.shadows.ShadowPowerManager");
    SHADOW_MAP.put("android.os.PowerManager.WakeLock", "org.robolectric.shadows.ShadowPowerManager$ShadowWakeLock");
    SHADOW_MAP.put("android.preference.Preference", "org.robolectric.shadows.ShadowPreference");
    SHADOW_MAP.put("android.os.Process", "org.robolectric.shadows.ShadowProcess");
    SHADOW_MAP.put("android.widget.ProgressBar", "org.robolectric.shadows.ShadowProgressBar");
    SHADOW_MAP.put("android.app.ProgressDialog", "org.robolectric.shadows.ShadowProgressDialog");
    SHADOW_MAP.put("android.graphics.Region", "org.robolectric.shadows.ShadowRegion");
    SHADOW_MAP.put("android.widget.RelativeLayout", "org.robolectric.shadows.ShadowRelativeLayout");
    SHADOW_MAP.put("android.os.RemoteCallbackList", "org.robolectric.shadows.ShadowRemoteCallbackList");
    SHADOW_MAP.put("android.content.pm.ResolveInfo", "org.robolectric.shadows.ShadowResolveInfo");
    SHADOW_MAP.put("android.widget.ResourceCursorAdapter", "org.robolectric.shadows.ShadowResourceCursorAdapter");
    SHADOW_MAP.put("android.content.res.Resources", "org.robolectric.shadows.ShadowResources");
    SHADOW_MAP.put("android.content.res.Resources.NotFoundException", "org.robolectric.shadows.ShadowResources$ShadowNotFoundException");
    SHADOW_MAP.put("android.content.res.Resources.Theme", "org.robolectric.shadows.ShadowResources$ShadowTheme");
    SHADOW_MAP.put("android.os.ResultReceiver", "org.robolectric.shadows.ShadowResultReceiver");
    SHADOW_MAP.put("android.database.sqlite.SQLiteConnection", "org.robolectric.shadows.ShadowSQLiteConnection");
    SHADOW_MAP.put("android.view.ScaleGestureDetector", "org.robolectric.shadows.ShadowScaleGestureDetector");
    SHADOW_MAP.put("android.net.wifi.ScanResult", "org.robolectric.shadows.ShadowScanResult");
    SHADOW_MAP.put("android.widget.ScrollView", "org.robolectric.shadows.ShadowScrollView");
    SHADOW_MAP.put("android.widget.Scroller", "org.robolectric.shadows.ShadowScroller");
    SHADOW_MAP.put("android.app.SearchManager", "org.robolectric.shadows.ShadowSearchManager");
    SHADOW_MAP.put("android.widget.SeekBar", "org.robolectric.shadows.ShadowSeekBar");
    SHADOW_MAP.put("android.hardware.SensorManager", "org.robolectric.shadows.ShadowSensorManager");
    SHADOW_MAP.put("android.app.Service", "org.robolectric.shadows.ShadowService");
    SHADOW_MAP.put("android.os.ServiceManager", "org.robolectric.shadows.ShadowServiceManager");
    SHADOW_MAP.put("android.provider.Settings", "org.robolectric.shadows.ShadowSettings");
    SHADOW_MAP.put("android.provider.Settings.Secure", "org.robolectric.shadows.ShadowSettings$ShadowSecure");
    SHADOW_MAP.put("android.provider.Settings.System", "org.robolectric.shadows.ShadowSettings$ShadowSystem");
    SHADOW_MAP.put("android.widget.SimpleCursorAdapter", "org.robolectric.shadows.ShadowSimpleCursorAdapter");
    SHADOW_MAP.put("dalvik.system.SocketTagger", "org.robolectric.shadows.ShadowSocketTagger");
    SHADOW_MAP.put("android.media.SoundPool", "org.robolectric.shadows.ShadowSoundPool");
    SHADOW_MAP.put("android.widget.SpellChecker", "org.robolectric.shadows.ShadowSpellChecker");
    SHADOW_MAP.put("android.webkit.SslErrorHandler", "org.robolectric.shadows.ShadowSslErrorHandler");
    SHADOW_MAP.put("android.os.StatFs", "org.robolectric.shadows.ShadowStatFs");
    SHADOW_MAP.put("android.graphics.drawable.StateListDrawable", "org.robolectric.shadows.ShadowStateListDrawable");
    SHADOW_MAP.put("android.text.StaticLayout", "org.robolectric.shadows.ShadowStaticLayout");
    SHADOW_MAP.put("android.os.StrictMode", "org.robolectric.shadows.ShadowStrictMode");
    SHADOW_MAP.put("android.view.Surface", "org.robolectric.shadows.ShadowSurface");
    SHADOW_MAP.put("android.view.SurfaceView", "org.robolectric.shadows.ShadowSurfaceView");
    SHADOW_MAP.put("android.os.SystemClock", "org.robolectric.shadows.ShadowSystemClock");
    SHADOW_MAP.put("android.os.SystemProperties", "org.robolectric.shadows.ShadowSystemProperties");
    SHADOW_MAP.put("android.app.TabActivity", "org.robolectric.shadows.ShadowTabActivity");
    SHADOW_MAP.put("android.widget.TabHost", "org.robolectric.shadows.ShadowTabHost");
    SHADOW_MAP.put("android.widget.TabHost.TabSpec", "org.robolectric.shadows.ShadowTabHost$ShadowTabSpec");
    SHADOW_MAP.put("android.widget.TabWidget", "org.robolectric.shadows.ShadowTabWidget");
    SHADOW_MAP.put("android.telephony.TelephonyManager", "org.robolectric.shadows.ShadowTelephonyManager");
    SHADOW_MAP.put("android.text.TextPaint", "org.robolectric.shadows.ShadowTextPaint");
    SHADOW_MAP.put("android.speech.tts.TextToSpeech", "org.robolectric.shadows.ShadowTextToSpeech");
    SHADOW_MAP.put("android.widget.TextView", "org.robolectric.shadows.ShadowTextView");
    SHADOW_MAP.put("android.text.format.Time", "org.robolectric.shadows.ShadowTime");
    SHADOW_MAP.put("android.app.TimePickerDialog", "org.robolectric.shadows.ShadowTimePickerDialog");
    SHADOW_MAP.put("android.widget.Toast", "org.robolectric.shadows.ShadowToast");
    SHADOW_MAP.put("android.view.TouchDelegate", "org.robolectric.shadows.ShadowTouchDelegate");
    SHADOW_MAP.put("android.net.TrafficStats", "org.robolectric.shadows.ShadowTrafficStats");
    SHADOW_MAP.put("android.content.res.TypedArray", "org.robolectric.shadows.ShadowTypedArray");
    SHADOW_MAP.put("android.graphics.Typeface", "org.robolectric.shadows.ShadowTypeface");
    SHADOW_MAP.put("dalvik.system.VMRuntime", "org.robolectric.shadows.ShadowVMRuntime");
    SHADOW_MAP.put("android.animation.ValueAnimator", "org.robolectric.shadows.ShadowValueAnimator");
    SHADOW_MAP.put("android.view.VelocityTracker", "org.robolectric.shadows.ShadowVelocityTracker");
    SHADOW_MAP.put("android.widget.VideoView", "org.robolectric.shadows.ShadowVideoView");
    SHADOW_MAP.put("android.view.View", "org.robolectric.shadows.ShadowView");
    SHADOW_MAP.put("android.widget.ViewAnimator", "org.robolectric.shadows.ShadowViewAnimator");
    SHADOW_MAP.put("android.view.ViewConfiguration", "org.robolectric.shadows.ShadowViewConfiguration");
    SHADOW_MAP.put("android.view.ViewGroup", "org.robolectric.shadows.ShadowViewGroup");
    SHADOW_MAP.put("android.view.ViewGroup.LayoutParams", "org.robolectric.shadows.ShadowViewGroup$ShadowLayoutParams");
    SHADOW_MAP.put("android.view.ViewGroup.MarginLayoutParams", "org.robolectric.shadows.ShadowViewGroup$ShadowMarginLayoutParams");
    SHADOW_MAP.put("android.view.ViewRootImpl", "org.robolectric.shadows.ShadowViewRootImpl");
    SHADOW_MAP.put("android.app.WallpaperManager", "org.robolectric.shadows.ShadowWallpaperManager");
    SHADOW_MAP.put("android.webkit.WebSyncManager", "org.robolectric.shadows.ShadowWebSyncManager");
    SHADOW_MAP.put("android.webkit.WebView", "org.robolectric.shadows.ShadowWebView");
    SHADOW_MAP.put("android.webkit.WebViewDatabase", "org.robolectric.shadows.ShadowWebViewDatabase");
    SHADOW_MAP.put("android.net.wifi.WifiConfiguration", "org.robolectric.shadows.ShadowWifiConfiguration");
    SHADOW_MAP.put("android.net.wifi.WifiInfo", "org.robolectric.shadows.ShadowWifiInfo");
    SHADOW_MAP.put("android.net.wifi.WifiManager", "org.robolectric.shadows.ShadowWifiManager");
    SHADOW_MAP.put("android.net.wifi.WifiManager.WifiLock", "org.robolectric.shadows.ShadowWifiManager$ShadowWifiLock");
    SHADOW_MAP.put("android.view.Window", "org.robolectric.shadows.ShadowWindow");
    SHADOW_MAP.put("android.view.WindowManager", "org.robolectric.shadows.ShadowWindowManager");
    SHADOW_MAP.put("android.view.WindowManagerImpl", "org.robolectric.shadows.ShadowWindowManagerImpl");
    SHADOW_MAP.put("android.widget.ZoomButtonsController", "org.robolectric.shadows.ShadowZoomButtonsController");
  }

  public static ShadowAbsListView shadowOf(AbsListView actual) {
    return (ShadowAbsListView) ShadowExtractor.extract(actual);
  }

  public static ShadowAbsSeekBar shadowOf(AbsSeekBar actual) {
    return (ShadowAbsSeekBar) ShadowExtractor.extract(actual);
  }

  public static ShadowAbsSpinner shadowOf(AbsSpinner actual) {
    return (ShadowAbsSpinner) ShadowExtractor.extract(actual);
  }

  public static ShadowAbsoluteLayout shadowOf(AbsoluteLayout actual) {
    return (ShadowAbsoluteLayout) ShadowExtractor.extract(actual);
  }

  public static ShadowAbsoluteLayout.ShadowLayoutParams shadowOf(AbsoluteLayout.LayoutParams actual) {
    return (ShadowAbsoluteLayout.ShadowLayoutParams) ShadowExtractor.extract(actual);
  }

  public static ShadowAbstractCursor shadowOf(AbstractCursor actual) {
    return (ShadowAbstractCursor) ShadowExtractor.extract(actual);
  }

  public static ShadowAccessibilityEvent shadowOf(AccessibilityEvent actual) {
    return (ShadowAccessibilityEvent) ShadowExtractor.extract(actual);
  }

  public static ShadowAccessibilityManager shadowOf(AccessibilityManager actual) {
    return (ShadowAccessibilityManager) ShadowExtractor.extract(actual);
  }

  public static ShadowAccessibilityNodeInfo shadowOf(AccessibilityNodeInfo actual) {
    return (ShadowAccessibilityNodeInfo) ShadowExtractor.extract(actual);
  }

  public static ShadowAccessibilityRecord shadowOf(AccessibilityRecord actual) {
    return (ShadowAccessibilityRecord) ShadowExtractor.extract(actual);
  }

  public static ShadowAccessibilityService shadowOf(AccessibilityService actual) {
    return (ShadowAccessibilityService) ShadowExtractor.extract(actual);
  }

  public static ShadowAccountManager shadowOf(AccountManager actual) {
    return (ShadowAccountManager) ShadowExtractor.extract(actual);
  }

  public static ShadowActivity shadowOf(Activity actual) {
    return (ShadowActivity) ShadowExtractor.extract(actual);
  }

  public static ShadowActivityGroup shadowOf(ActivityGroup actual) {
    return (ShadowActivityGroup) ShadowExtractor.extract(actual);
  }

  public static ShadowActivityManager shadowOf(ActivityManager actual) {
    return (ShadowActivityManager) ShadowExtractor.extract(actual);
  }

  public static <T extends Adapter> ShadowAdapterView<T> shadowOf(AdapterView<T> actual) {
    return (ShadowAdapterView<T>) ShadowExtractor.extract(actual);
  }

  public static ShadowAlarmManager shadowOf(AlarmManager actual) {
    return (ShadowAlarmManager) ShadowExtractor.extract(actual);
  }

  public static ShadowAlertDialog shadowOf(AlertDialog actual) {
    return (ShadowAlertDialog) ShadowExtractor.extract(actual);
  }

  public static ShadowBuilder shadowOf(Builder actual) {
    return (ShadowBuilder) ShadowExtractor.extract(actual);
  }

  public static ShadowAnimationUtils shadowOf(AnimationUtils actual) {
    return (ShadowAnimationUtils) ShadowExtractor.extract(actual);
  }

  public static ShadowAppWidgetHost shadowOf(AppWidgetHost actual) {
    return (ShadowAppWidgetHost) ShadowExtractor.extract(actual);
  }

  public static ShadowAppWidgetHostView shadowOf(AppWidgetHostView actual) {
    return (ShadowAppWidgetHostView) ShadowExtractor.extract(actual);
  }

  public static ShadowAppWidgetManager shadowOf(AppWidgetManager actual) {
    return (ShadowAppWidgetManager) ShadowExtractor.extract(actual);
  }

  public static ShadowApplication shadowOf(Application actual) {
    return (ShadowApplication) ShadowExtractor.extract(actual);
  }

  public static <T> ShadowArrayAdapter<T> shadowOf(ArrayAdapter<T> actual) {
    return (ShadowArrayAdapter<T>) ShadowExtractor.extract(actual);
  }

  public static ShadowAssetManager shadowOf(AssetManager actual) {
    return (ShadowAssetManager) ShadowExtractor.extract(actual);
  }

  public static <Params,Progress,Result> ShadowAsyncTask<Params,Progress,Result> shadowOf(AsyncTask<Params,Progress,Result> actual) {
    return (ShadowAsyncTask<Params,Progress,Result>) ShadowExtractor.extract(actual);
  }

  public static <D> ShadowAsyncTaskLoader<D> shadowOf(AsyncTaskLoader<D> actual) {
    return (ShadowAsyncTaskLoader<D>) ShadowExtractor.extract(actual);
  }

  public static ShadowAudioEffect shadowOf(AudioEffect actual) {
    return (ShadowAudioEffect) ShadowExtractor.extract(actual);
  }

  public static ShadowAudioManager shadowOf(AudioManager actual) {
    return (ShadowAudioManager) ShadowExtractor.extract(actual);
  }

  public static ShadowBaseAdapter shadowOf(BaseAdapter actual) {
    return (ShadowBaseAdapter) ShadowExtractor.extract(actual);
  }

  public static ShadowBinder shadowOf(Binder actual) {
    return (ShadowBinder) ShadowExtractor.extract(actual);
  }

  public static ShadowBitmap shadowOf(Bitmap actual) {
    return (ShadowBitmap) ShadowExtractor.extract(actual);
  }

  public static ShadowBitmapDrawable shadowOf(BitmapDrawable actual) {
    return (ShadowBitmapDrawable) ShadowExtractor.extract(actual);
  }

  public static ShadowBitmapFactory shadowOf(BitmapFactory actual) {
    return (ShadowBitmapFactory) ShadowExtractor.extract(actual);
  }

  public static ShadowBitmapShader shadowOf(BitmapShader actual) {
    return (ShadowBitmapShader) ShadowExtractor.extract(actual);
  }

  public static ShadowBluetoothAdapter shadowOf(BluetoothAdapter actual) {
    return (ShadowBluetoothAdapter) ShadowExtractor.extract(actual);
  }

  public static ShadowBluetoothDevice shadowOf(BluetoothDevice actual) {
    return (ShadowBluetoothDevice) ShadowExtractor.extract(actual);
  }

  public static ShadowBroadcastPendingResult shadowOf(PendingResult actual) {
    return (ShadowBroadcastPendingResult) ShadowExtractor.extract(actual);
  }

  public static ShadowBroadcastReceiver shadowOf(BroadcastReceiver actual) {
    return (ShadowBroadcastReceiver) ShadowExtractor.extract(actual);
  }

  public static ShadowCamera shadowOf(Camera actual) {
    return (ShadowCamera) ShadowExtractor.extract(actual);
  }

  public static ShadowParameters shadowOf(Parameters actual) {
    return (ShadowParameters) ShadowExtractor.extract(actual);
  }

  public static ShadowSize shadowOf(Size actual) {
    return (ShadowSize) ShadowExtractor.extract(actual);
  }

  public static ShadowCanvas shadowOf(Canvas actual) {
    return (ShadowCanvas) ShadowExtractor.extract(actual);
  }

  public static ShadowChoreographer shadowOf(Choreographer actual) {
    return (ShadowChoreographer) ShadowExtractor.extract(actual);
  }

  public static ShadowClipboardManager shadowOf(ClipboardManager actual) {
    return (ShadowClipboardManager) ShadowExtractor.extract(actual);
  }

  public static ShadowColor shadowOf(Color actual) {
    return (ShadowColor) ShadowExtractor.extract(actual);
  }

  public static ShadowColorMatrix shadowOf(ColorMatrix actual) {
    return (ShadowColorMatrix) ShadowExtractor.extract(actual);
  }

  public static ShadowColorMatrixColorFilter shadowOf(ColorMatrixColorFilter actual) {
    return (ShadowColorMatrixColorFilter) ShadowExtractor.extract(actual);
  }

  public static ShadowCompoundButton shadowOf(CompoundButton actual) {
    return (ShadowCompoundButton) ShadowExtractor.extract(actual);
  }

  public static ShadowConfiguration shadowOf(Configuration actual) {
    return (ShadowConfiguration) ShadowExtractor.extract(actual);
  }

  public static ShadowConnectivityManager shadowOf(ConnectivityManager actual) {
    return (ShadowConnectivityManager) ShadowExtractor.extract(actual);
  }

  public static ShadowContentObserver shadowOf(ContentObserver actual) {
    return (ShadowContentObserver) ShadowExtractor.extract(actual);
  }

  public static ShadowContentProvider shadowOf(ContentProvider actual) {
    return (ShadowContentProvider) ShadowExtractor.extract(actual);
  }

  public static ShadowContentProviderClient shadowOf(ContentProviderClient actual) {
    return (ShadowContentProviderClient) ShadowExtractor.extract(actual);
  }

  public static ShadowContentProviderOperation shadowOf(ContentProviderOperation actual) {
    return (ShadowContentProviderOperation) ShadowExtractor.extract(actual);
  }

  public static ShadowContentProviderResult shadowOf(ContentProviderResult actual) {
    return (ShadowContentProviderResult) ShadowExtractor.extract(actual);
  }

  public static ShadowContentResolver shadowOf(ContentResolver actual) {
    return (ShadowContentResolver) ShadowExtractor.extract(actual);
  }

  public static ShadowContentUris shadowOf(ContentUris actual) {
    return (ShadowContentUris) ShadowExtractor.extract(actual);
  }

  public static ShadowContextThemeWrapper shadowOf(ContextThemeWrapper actual) {
    return (ShadowContextThemeWrapper) ShadowExtractor.extract(actual);
  }

  public static ShadowContextWrapper shadowOf(ContextWrapper actual) {
    return (ShadowContextWrapper) ShadowExtractor.extract(actual);
  }

  public static ShadowCookieManager shadowOf(CookieManager actual) {
    return (ShadowCookieManager) ShadowExtractor.extract(actual);
  }

  public static ShadowCookieSyncManager shadowOf(CookieSyncManager actual) {
    return (ShadowCookieSyncManager) ShadowExtractor.extract(actual);
  }

  public static ShadowCornerPathEffect shadowOf(CornerPathEffect actual) {
    return (ShadowCornerPathEffect) ShadowExtractor.extract(actual);
  }

  public static ShadowCountDownTimer shadowOf(CountDownTimer actual) {
    return (ShadowCountDownTimer) ShadowExtractor.extract(actual);
  }

  public static ShadowCursorAdapter shadowOf(CursorAdapter actual) {
    return (ShadowCursorAdapter) ShadowExtractor.extract(actual);
  }

  public static ShadowCursorWindow shadowOf(CursorWindow actual) {
    return (ShadowCursorWindow) ShadowExtractor.extract(actual);
  }

  public static ShadowCursorWrapper shadowOf(CursorWrapper actual) {
    return (ShadowCursorWrapper) ShadowExtractor.extract(actual);
  }

  public static ShadowDashPathEffect shadowOf(DashPathEffect actual) {
    return (ShadowDashPathEffect) ShadowExtractor.extract(actual);
  }

  public static ShadowDateFormat shadowOf(DateFormat actual) {
    return (ShadowDateFormat) ShadowExtractor.extract(actual);
  }

  public static ShadowDatePickerDialog shadowOf(DatePickerDialog actual) {
    return (ShadowDatePickerDialog) ShadowExtractor.extract(actual);
  }

  public static ShadowDebug shadowOf(Debug actual) {
    return (ShadowDebug) ShadowExtractor.extract(actual);
  }

  public static ShadowDialog shadowOf(Dialog actual) {
    return (ShadowDialog) ShadowExtractor.extract(actual);
  }

  public static ShadowDisplay shadowOf(Display actual) {
    return (ShadowDisplay) ShadowExtractor.extract(actual);
  }

  public static ShadowDownloadManager shadowOf(DownloadManager actual) {
    return (ShadowDownloadManager) ShadowExtractor.extract(actual);
  }

  public static ShadowQuery shadowOf(Query actual) {
    return (ShadowQuery) ShadowExtractor.extract(actual);
  }

  public static ShadowRequest shadowOf(Request actual) {
    return (ShadowRequest) ShadowExtractor.extract(actual);
  }

  public static ShadowDrawable shadowOf(Drawable actual) {
    return (ShadowDrawable) ShadowExtractor.extract(actual);
  }

  public static ShadowEdgeEffect shadowOf(EdgeEffect actual) {
    return (ShadowEdgeEffect) ShadowExtractor.extract(actual);
  }

  public static ShadowEnvironment shadowOf(Environment actual) {
    return (ShadowEnvironment) ShadowExtractor.extract(actual);
  }

  public static ShadowExifInterface shadowOf(ExifInterface actual) {
    return (ShadowExifInterface) ShadowExtractor.extract(actual);
  }

  public static ShadowExpandableListView shadowOf(ExpandableListView actual) {
    return (ShadowExpandableListView) ShadowExtractor.extract(actual);
  }

  public static ShadowFilter shadowOf(Filter actual) {
    return (ShadowFilter) ShadowExtractor.extract(actual);
  }

  public static ShadowFloatMath shadowOf(FloatMath actual) {
    return (ShadowFloatMath) ShadowExtractor.extract(actual);
  }

  public static ShadowFrameLayout shadowOf(FrameLayout actual) {
    return (ShadowFrameLayout) ShadowExtractor.extract(actual);
  }

  public static ShadowGestureDetector shadowOf(GestureDetector actual) {
    return (ShadowGestureDetector) ShadowExtractor.extract(actual);
  }

  public static ShadowGradientDrawable shadowOf(GradientDrawable actual) {
    return (ShadowGradientDrawable) ShadowExtractor.extract(actual);
  }

  public static ShadowHandler shadowOf(Handler actual) {
    return (ShadowHandler) ShadowExtractor.extract(actual);
  }

  public static ShadowHttpResponseCache shadowOf(HttpResponseCache actual) {
    return (ShadowHttpResponseCache) ShadowExtractor.extract(actual);
  }

  public static ShadowImageView shadowOf(ImageView actual) {
    return (ShadowImageView) ShadowExtractor.extract(actual);
  }

  public static ShadowInputDevice shadowOf(InputDevice actual) {
    return (ShadowInputDevice) ShadowExtractor.extract(actual);
  }

  public static ShadowInputEvent shadowOf(InputEvent actual) {
    return (ShadowInputEvent) ShadowExtractor.extract(actual);
  }

  public static ShadowInputMethodManager shadowOf(InputMethodManager actual) {
    return (ShadowInputMethodManager) ShadowExtractor.extract(actual);
  }

  public static ShadowIntent shadowOf(Intent actual) {
    return (ShadowIntent) ShadowExtractor.extract(actual);
  }

  public static ShadowIntentFilter shadowOf(IntentFilter actual) {
    return (ShadowIntentFilter) ShadowExtractor.extract(actual);
  }

  public static ShadowAuthorityEntry shadowOf(AuthorityEntry actual) {
    return (ShadowAuthorityEntry) ShadowExtractor.extract(actual);
  }

  public static ShadowIntentService shadowOf(IntentService actual) {
    return (ShadowIntentService) ShadowExtractor.extract(actual);
  }

  public static ShadowJsPromptResult shadowOf(JsPromptResult actual) {
    return (ShadowJsPromptResult) ShadowExtractor.extract(actual);
  }

  public static ShadowJsResult shadowOf(JsResult actual) {
    return (ShadowJsResult) ShadowExtractor.extract(actual);
  }

  public static ShadowKeyCharacterMap shadowOf(KeyCharacterMap actual) {
    return (ShadowKeyCharacterMap) ShadowExtractor.extract(actual);
  }

  public static ShadowKeyguardManager shadowOf(KeyguardManager actual) {
    return (ShadowKeyguardManager) ShadowExtractor.extract(actual);
  }

  public static ShadowKeyguardLock shadowOf(KeyguardLock actual) {
    return (ShadowKeyguardLock) ShadowExtractor.extract(actual);
  }

  public static ShadowLayoutAnimationController shadowOf(LayoutAnimationController actual) {
    return (ShadowLayoutAnimationController) ShadowExtractor.extract(actual);
  }

  public static ShadowLinearGradient shadowOf(LinearGradient actual) {
    return (ShadowLinearGradient) ShadowExtractor.extract(actual);
  }

  public static ShadowLinearLayout shadowOf(LinearLayout actual) {
    return (ShadowLinearLayout) ShadowExtractor.extract(actual);
  }

  public static ShadowLinkMovementMethod shadowOf(LinkMovementMethod actual) {
    return (ShadowLinkMovementMethod) ShadowExtractor.extract(actual);
  }

  public static ShadowListPopupWindow shadowOf(ListPopupWindow actual) {
    return (ShadowListPopupWindow) ShadowExtractor.extract(actual);
  }

  public static ShadowListView shadowOf(ListView actual) {
    return (ShadowListView) ShadowExtractor.extract(actual);
  }

  public static ShadowLocalActivityManager shadowOf(LocalActivityManager actual) {
    return (ShadowLocalActivityManager) ShadowExtractor.extract(actual);
  }

  public static ShadowLocation shadowOf(Location actual) {
    return (ShadowLocation) ShadowExtractor.extract(actual);
  }

  public static ShadowLocationManager shadowOf(LocationManager actual) {
    return (ShadowLocationManager) ShadowExtractor.extract(actual);
  }

  public static ShadowLog shadowOf(Log actual) {
    return (ShadowLog) ShadowExtractor.extract(actual);
  }

  public static ShadowLooper shadowOf(Looper actual) {
    return (ShadowLooper) ShadowExtractor.extract(actual);
  }

  public static ShadowMatrix shadowOf(Matrix actual) {
    return (ShadowMatrix) ShadowExtractor.extract(actual);
  }

  public static ShadowMediaMetadataRetriever shadowOf(MediaMetadataRetriever actual) {
    return (ShadowMediaMetadataRetriever) ShadowExtractor.extract(actual);
  }

  public static ShadowMediaPlayer shadowOf(MediaPlayer actual) {
    return (ShadowMediaPlayer) ShadowExtractor.extract(actual);
  }

  public static ShadowMediaRecorder shadowOf(MediaRecorder actual) {
    return (ShadowMediaRecorder) ShadowExtractor.extract(actual);
  }

  public static ShadowMediaRouter shadowOf(MediaRouter actual) {
    return (ShadowMediaRouter) ShadowExtractor.extract(actual);
  }

  public static ShadowMediaScannerConnection shadowOf(MediaScannerConnection actual) {
    return (ShadowMediaScannerConnection) ShadowExtractor.extract(actual);
  }

  public static ShadowMediaStore shadowOf(MediaStore actual) {
    return (ShadowMediaStore) ShadowExtractor.extract(actual);
  }

  public static ShadowImages shadowOf(Images actual) {
    return (ShadowImages) ShadowExtractor.extract(actual);
  }

  public static ShadowMedia shadowOf(Media actual) {
    return (ShadowMedia) ShadowExtractor.extract(actual);
  }

  public static ShadowMessage shadowOf(Message actual) {
    return (ShadowMessage) ShadowExtractor.extract(actual);
  }

  public static ShadowMessageQueue shadowOf(MessageQueue actual) {
    return (ShadowMessageQueue) ShadowExtractor.extract(actual);
  }

  public static ShadowMessenger shadowOf(Messenger actual) {
    return (ShadowMessenger) ShadowExtractor.extract(actual);
  }

  public static ShadowMimeTypeMap shadowOf(MimeTypeMap actual) {
    return (ShadowMimeTypeMap) ShadowExtractor.extract(actual);
  }

  public static ShadowMotionEvent shadowOf(MotionEvent actual) {
    return (ShadowMotionEvent) ShadowExtractor.extract(actual);
  }

  public static ShadowNetworkInfo shadowOf(NetworkInfo actual) {
    return (ShadowNetworkInfo) ShadowExtractor.extract(actual);
  }

  public static ShadowNfcAdapter shadowOf(NfcAdapter actual) {
    return (ShadowNfcAdapter) ShadowExtractor.extract(actual);
  }

  public static ShadowNinePatch shadowOf(NinePatch actual) {
    return (ShadowNinePatch) ShadowExtractor.extract(actual);
  }

  public static ShadowNotification shadowOf(Notification actual) {
    return (ShadowNotification) ShadowExtractor.extract(actual);
  }

  public static ShadowNotificationManager shadowOf(NotificationManager actual) {
    return (ShadowNotificationManager) ShadowExtractor.extract(actual);
  }

  public static ShadowNumberPicker shadowOf(NumberPicker actual) {
    return (ShadowNumberPicker) ShadowExtractor.extract(actual);
  }

  public static ShadowObjectAnimator shadowOf(ObjectAnimator actual) {
    return (ShadowObjectAnimator) ShadowExtractor.extract(actual);
  }

  public static ShadowOverScroller shadowOf(OverScroller actual) {
    return (ShadowOverScroller) ShadowExtractor.extract(actual);
  }

  public static ShadowPaint shadowOf(Paint actual) {
    return (ShadowPaint) ShadowExtractor.extract(actual);
  }

  public static ShadowParcel shadowOf(Parcel actual) {
    return (ShadowParcel) ShadowExtractor.extract(actual);
  }

  public static ShadowParcelFileDescriptor shadowOf(ParcelFileDescriptor actual) {
    return (ShadowParcelFileDescriptor) ShadowExtractor.extract(actual);
  }

  public static ShadowPath shadowOf(Path actual) {
    return (ShadowPath) ShadowExtractor.extract(actual);
  }

  public static ShadowPendingIntent shadowOf(PendingIntent actual) {
    return (ShadowPendingIntent) ShadowExtractor.extract(actual);
  }

  public static ShadowPicture shadowOf(Picture actual) {
    return (ShadowPicture) ShadowExtractor.extract(actual);
  }

  public static ShadowPopupMenu shadowOf(PopupMenu actual) {
    return (ShadowPopupMenu) ShadowExtractor.extract(actual);
  }

  public static ShadowPopupWindow shadowOf(PopupWindow actual) {
    return (ShadowPopupWindow) ShadowExtractor.extract(actual);
  }

  public static ShadowPorterDuffColorFilter shadowOf(PorterDuffColorFilter actual) {
    return (ShadowPorterDuffColorFilter) ShadowExtractor.extract(actual);
  }

  public static ShadowPowerManager shadowOf(PowerManager actual) {
    return (ShadowPowerManager) ShadowExtractor.extract(actual);
  }

  public static ShadowWakeLock shadowOf(WakeLock actual) {
    return (ShadowWakeLock) ShadowExtractor.extract(actual);
  }

  public static ShadowPreference shadowOf(Preference actual) {
    return (ShadowPreference) ShadowExtractor.extract(actual);
  }

  public static ShadowProcess shadowOf(Process actual) {
    return (ShadowProcess) ShadowExtractor.extract(actual);
  }

  public static ShadowProgressBar shadowOf(ProgressBar actual) {
    return (ShadowProgressBar) ShadowExtractor.extract(actual);
  }

  public static ShadowProgressDialog shadowOf(ProgressDialog actual) {
    return (ShadowProgressDialog) ShadowExtractor.extract(actual);
  }

  public static ShadowRegion shadowOf(Region actual) {
    return (ShadowRegion) ShadowExtractor.extract(actual);
  }

  public static ShadowRelativeLayout shadowOf(RelativeLayout actual) {
    return (ShadowRelativeLayout) ShadowExtractor.extract(actual);
  }

  public static <E extends IInterface> ShadowRemoteCallbackList<E> shadowOf(RemoteCallbackList<E> actual) {
    return (ShadowRemoteCallbackList<E>) ShadowExtractor.extract(actual);
  }

  public static ShadowResolveInfo shadowOf(ResolveInfo actual) {
    return (ShadowResolveInfo) ShadowExtractor.extract(actual);
  }

  public static ShadowResourceCursorAdapter shadowOf(ResourceCursorAdapter actual) {
    return (ShadowResourceCursorAdapter) ShadowExtractor.extract(actual);
  }

  public static ShadowResources shadowOf(Resources actual) {
    return (ShadowResources) ShadowExtractor.extract(actual);
  }

  public static ShadowNotFoundException shadowOf(NotFoundException actual) {
    return (ShadowNotFoundException) ShadowExtractor.extract(actual);
  }

  public static ShadowTheme shadowOf(Theme actual) {
    return (ShadowTheme) ShadowExtractor.extract(actual);
  }

  public static ShadowResultReceiver shadowOf(ResultReceiver actual) {
    return (ShadowResultReceiver) ShadowExtractor.extract(actual);
  }

  public static ShadowScaleGestureDetector shadowOf(ScaleGestureDetector actual) {
    return (ShadowScaleGestureDetector) ShadowExtractor.extract(actual);
  }

  public static ShadowScanResult shadowOf(ScanResult actual) {
    return (ShadowScanResult) ShadowExtractor.extract(actual);
  }

  public static ShadowScrollView shadowOf(ScrollView actual) {
    return (ShadowScrollView) ShadowExtractor.extract(actual);
  }

  public static ShadowScroller shadowOf(Scroller actual) {
    return (ShadowScroller) ShadowExtractor.extract(actual);
  }

  public static ShadowSearchManager shadowOf(SearchManager actual) {
    return (ShadowSearchManager) ShadowExtractor.extract(actual);
  }

  public static ShadowSeekBar shadowOf(SeekBar actual) {
    return (ShadowSeekBar) ShadowExtractor.extract(actual);
  }

  public static ShadowSensorManager shadowOf(SensorManager actual) {
    return (ShadowSensorManager) ShadowExtractor.extract(actual);
  }

  public static ShadowService shadowOf(Service actual) {
    return (ShadowService) ShadowExtractor.extract(actual);
  }

  public static ShadowSettings shadowOf(Settings actual) {
    return (ShadowSettings) ShadowExtractor.extract(actual);
  }

  public static ShadowSecure shadowOf(Secure actual) {
    return (ShadowSecure) ShadowExtractor.extract(actual);
  }

  public static ShadowSystem shadowOf(System actual) {
    return (ShadowSystem) ShadowExtractor.extract(actual);
  }

  public static ShadowSimpleCursorAdapter shadowOf(SimpleCursorAdapter actual) {
    return (ShadowSimpleCursorAdapter) ShadowExtractor.extract(actual);
  }

  public static ShadowSoundPool shadowOf(SoundPool actual) {
    return (ShadowSoundPool) ShadowExtractor.extract(actual);
  }

  public static ShadowSslErrorHandler shadowOf(SslErrorHandler actual) {
    return (ShadowSslErrorHandler) ShadowExtractor.extract(actual);
  }

  public static ShadowStatFs shadowOf(StatFs actual) {
    return (ShadowStatFs) ShadowExtractor.extract(actual);
  }

  public static ShadowStateListDrawable shadowOf(StateListDrawable actual) {
    return (ShadowStateListDrawable) ShadowExtractor.extract(actual);
  }

  public static ShadowStaticLayout shadowOf(StaticLayout actual) {
    return (ShadowStaticLayout) ShadowExtractor.extract(actual);
  }

  public static ShadowStrictMode shadowOf(StrictMode actual) {
    return (ShadowStrictMode) ShadowExtractor.extract(actual);
  }

  public static ShadowSurface shadowOf(Surface actual) {
    return (ShadowSurface) ShadowExtractor.extract(actual);
  }

  public static ShadowSurfaceView shadowOf(SurfaceView actual) {
    return (ShadowSurfaceView) ShadowExtractor.extract(actual);
  }

  public static ShadowSystemClock shadowOf(SystemClock actual) {
    return (ShadowSystemClock) ShadowExtractor.extract(actual);
  }

  public static ShadowTabActivity shadowOf(TabActivity actual) {
    return (ShadowTabActivity) ShadowExtractor.extract(actual);
  }

  public static ShadowTabHost shadowOf(TabHost actual) {
    return (ShadowTabHost) ShadowExtractor.extract(actual);
  }

  public static ShadowTabSpec shadowOf(TabSpec actual) {
    return (ShadowTabSpec) ShadowExtractor.extract(actual);
  }

  public static ShadowTabWidget shadowOf(TabWidget actual) {
    return (ShadowTabWidget) ShadowExtractor.extract(actual);
  }

  public static ShadowTelephonyManager shadowOf(TelephonyManager actual) {
    return (ShadowTelephonyManager) ShadowExtractor.extract(actual);
  }

  public static ShadowTextPaint shadowOf(TextPaint actual) {
    return (ShadowTextPaint) ShadowExtractor.extract(actual);
  }

  public static ShadowTextToSpeech shadowOf(TextToSpeech actual) {
    return (ShadowTextToSpeech) ShadowExtractor.extract(actual);
  }

  public static ShadowTextView shadowOf(TextView actual) {
    return (ShadowTextView) ShadowExtractor.extract(actual);
  }

  public static ShadowTime shadowOf(Time actual) {
    return (ShadowTime) ShadowExtractor.extract(actual);
  }

  public static ShadowTimePickerDialog shadowOf(TimePickerDialog actual) {
    return (ShadowTimePickerDialog) ShadowExtractor.extract(actual);
  }

  public static ShadowToast shadowOf(Toast actual) {
    return (ShadowToast) ShadowExtractor.extract(actual);
  }

  public static ShadowTouchDelegate shadowOf(TouchDelegate actual) {
    return (ShadowTouchDelegate) ShadowExtractor.extract(actual);
  }

  public static ShadowTrafficStats shadowOf(TrafficStats actual) {
    return (ShadowTrafficStats) ShadowExtractor.extract(actual);
  }

  public static ShadowTypedArray shadowOf(TypedArray actual) {
    return (ShadowTypedArray) ShadowExtractor.extract(actual);
  }

  public static ShadowTypeface shadowOf(Typeface actual) {
    return (ShadowTypeface) ShadowExtractor.extract(actual);
  }

  public static ShadowValueAnimator shadowOf(ValueAnimator actual) {
    return (ShadowValueAnimator) ShadowExtractor.extract(actual);
  }

  public static ShadowVelocityTracker shadowOf(VelocityTracker actual) {
    return (ShadowVelocityTracker) ShadowExtractor.extract(actual);
  }

  public static ShadowVideoView shadowOf(VideoView actual) {
    return (ShadowVideoView) ShadowExtractor.extract(actual);
  }

  public static ShadowView shadowOf(View actual) {
    return (ShadowView) ShadowExtractor.extract(actual);
  }

  public static ShadowViewAnimator shadowOf(ViewAnimator actual) {
    return (ShadowViewAnimator) ShadowExtractor.extract(actual);
  }

  public static ShadowViewConfiguration shadowOf(ViewConfiguration actual) {
    return (ShadowViewConfiguration) ShadowExtractor.extract(actual);
  }

  public static ShadowViewGroup shadowOf(ViewGroup actual) {
    return (ShadowViewGroup) ShadowExtractor.extract(actual);
  }

  public static ShadowViewGroup.ShadowLayoutParams shadowOf(ViewGroup.LayoutParams actual) {
    return (ShadowViewGroup.ShadowLayoutParams) ShadowExtractor.extract(actual);
  }

  public static ShadowMarginLayoutParams shadowOf(MarginLayoutParams actual) {
    return (ShadowMarginLayoutParams) ShadowExtractor.extract(actual);
  }

  public static ShadowWallpaperManager shadowOf(WallpaperManager actual) {
    return (ShadowWallpaperManager) ShadowExtractor.extract(actual);
  }

  public static ShadowWebView shadowOf(WebView actual) {
    return (ShadowWebView) ShadowExtractor.extract(actual);
  }

  public static ShadowWebViewDatabase shadowOf(WebViewDatabase actual) {
    return (ShadowWebViewDatabase) ShadowExtractor.extract(actual);
  }

  public static ShadowWifiConfiguration shadowOf(WifiConfiguration actual) {
    return (ShadowWifiConfiguration) ShadowExtractor.extract(actual);
  }

  public static ShadowWifiInfo shadowOf(WifiInfo actual) {
    return (ShadowWifiInfo) ShadowExtractor.extract(actual);
  }

  public static ShadowWifiManager shadowOf(WifiManager actual) {
    return (ShadowWifiManager) ShadowExtractor.extract(actual);
  }

  public static ShadowWifiLock shadowOf(WifiLock actual) {
    return (ShadowWifiLock) ShadowExtractor.extract(actual);
  }

  public static ShadowWindow shadowOf(Window actual) {
    return (ShadowWindow) ShadowExtractor.extract(actual);
  }

  public static ShadowWindowManager shadowOf(WindowManager actual) {
    return (ShadowWindowManager) ShadowExtractor.extract(actual);
  }

  public static ShadowZoomButtonsController shadowOf(ZoomButtonsController actual) {
    return (ShadowZoomButtonsController) ShadowExtractor.extract(actual);
  }

  public void reset() {
    ShadowAccountManager.reset();
    ShadowAudioEffect.reset();
    ShadowBinder.reset();
    ShadowBitmapFactory.reset();
    ShadowChoreographer.reset();
    ShadowContentResolver.reset();
    ShadowCookieManager.resetCookies();
    ShadowDialog.reset();
    ShadowDrawable.clearCorruptStreamSources();
    ShadowEnvironment.reset();
    ShadowLog.reset();
    ShadowLooper.resetThreadLoopers();
    ShadowMediaMetadataRetriever.reset();
    ShadowMediaPlayer.resetStaticState();
    ShadowMessage.reset();
    ShadowMimeTypeMap.reset();
    ShadowPendingIntent.reset();
    ShadowPowerManager.reset();
    ShadowProcess.reset();
    ShadowResources.reset();
    ShadowSQLiteConnection.reset();
    ShadowStatFs.reset();
    ShadowTypeface.reset();
    ShadowValueAnimator.reset();
  }

  @Override
  public Map<String, String> getShadowMap() {
    return SHADOW_MAP;
  }

  @Override
  public String[] getProvidedPackageNames() {
    return new String[] {"android.media.audiofx","android.bluetooth","android.hardware","android.provider","android.accessibilityservice","android.view.inputmethod","android.widget","android.media","android.nfc","android.speech.tts","android.location","android.content.pm","android.view.animation","android.text.method","android.preference","android.content","android.net.wifi","android.content.res","android.view","android.graphics.drawable","android.text.format","android.accounts","android.util","android.telephony","android.animation","android.net","android.net.http","android.app","android.text","android.webkit","android.database","android.view.accessibility","android.os","android.appwidget","android.graphics"};
  }
}
